import Vue from "vue";
import Vuex from "vuex";

Vue.use(Vuex);

const examHomeModule = {
  namespaced: true,
  state: { faceCheckModalOpen: false },
  mutations: {
    toggleFaceCheckModal(state, open) {
      if (open === undefined) {
        state.faceCheckModalOpen = !state.faceCheckModalOpen;
      } else {
        state.faceCheckModalOpen = open;
      }
    }
  },
  actions: {},
  getters: {}
};

const examingHomeModule = {
  namespaced: true,
  state: {
    exam: null,
    paperStruct: null,
    examQuestionList: null,
    questionFilterType: "ALL"
  },
  mutations: {
    updateExamState(state, payload) {
      state = Object.assign(state, payload);
    },
    updateQuestionFilter(state, type) {
      state.questionFilterType = type;
    },
    updateExamQuestionAnswer(state, { examQuestionId, stuAnswer }) {
      state.examQuestionList = state.examQuestionList.map(eq => {
        if (eq.id === examQuestionId) {
          return Object.assign({}, eq, { stuAnswer });
        }
        return eq;
      });
    }
  },
  actions: {},
  getters: {
    validQuestions: state => {
      return (
        state.examQuestionList &&
        state.examQuestionList.filter(q => q.nestedQuestion === false)
      );
    }
  }
};

let initUser = {};
if (process.env.NODE_ENV !== "production") {
  const userStr = window.localStorage.getItem("user");
  initUser = JSON.parse(userStr);
}

export default new Vuex.Store({
  state: {
    user: initUser
  },
  mutations: {},
  actions: {},
  modules: {
    examHomeModule,
    examingHomeModule
  }
});
